@@ -7,14 +7,18 @@ you didn't get a copy, you may request one from <license@inner.net>.
 
 */
 
+#include "config.h"
 #include <sys/types.h>
 #include <stdio.h>
+#ifdef HAVE_NET_SOCKET_H
+#include <net/socket.h>
+#else
 #include <sys/socket.h>
+#endif
 #include <netinet/in.h>
 #include <errno.h>
 #include <netdb.h>
 #include <signal.h>
-#include "config.h"
 
 #ifndef SA_LEN
 #define SA_LEN(sa)	((sa)->sa_len)
