@@ -12,13 +12,13 @@ $wwwhost = $ENV{'WWWVIRTUAL'};
 my($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = localtime(time);
 $month = $months[$mon];
 
-$century = 19 + int($year / 100);
+$year += 1900;
 
 print <<EOF;
 Begin3
 Title:		fetchmail
 Version:	$version
-Entered-date:	${mday}${month}${century}${year}
+Entered-date:	${mday}${month}${year}
 Description:	Full-featured IMAP/POP2/POP3/APOP/RPOP/KPOP client with GUI
 		configuration, daemon mode, forwarding via SMTP or local MDA,
 		superior reply handling, support for multidrop mailboxes. 
